@@ -1,11 +1,9 @@
 package Benchmark::Perl::Formance;
-# git description: v0.42-3-g5b7d214
-
 BEGIN {
   $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Perl 5 performance benchmarking framework
-$Benchmark::Perl::Formance::VERSION = '0.43';
+$Benchmark::Perl::Formance::VERSION = '0.44';
 use 5.008;
 
 use warnings;
@@ -451,6 +449,16 @@ sub _get_perlformance_config {
         return map { $self->{options}{$_} ? ("perlformance_$_" => $self->{options}{$_}) : () } @config_keys;
 }
 
+sub _get_perlformance_env
+{
+        my ($self) = @_;
+
+        # environment variables matching /^PERLFORMANCE_/
+        my @config_keys = grep { $ENV{$_} ne '' } grep /^PERLFORMANCE_/, keys %ENV;
+
+        return map { lc("env_$_") => $ENV{$_} } @config_keys;
+}
+
 sub _get_platforminfo {
         my ($self) = @_;
 
@@ -525,6 +533,7 @@ sub generate_BenchmarkAnythingData_data
                      $self->_get_perl_config_v,
                      $self->_get_sysinfo,
                      $self->_get_perlformance_config,
+                     $self->_get_perlformance_env,
                     );
         return $self->augment_results_with_meta("NAME", "VALUE", \%META, $RESULTS);
 }
@@ -539,6 +548,8 @@ sub run {
         my $platforminfo   = 0;
         my $codespeed      = 0;
         my $tapper         = 0;
+        my $benchmarkanything = 0;
+        my $benchmarkanything_report = 0;
         my $cs_executable_suffix = "";
         my $cs_executable        = "";
         my $cs_project           = "";
@@ -573,6 +584,8 @@ sub run {
                              "platforminfo|p"   => \$platforminfo,
                              "codespeed"        => \$codespeed,
                              "tapper"           => \$tapper,
+                             "benchmarkanything" => \$benchmarkanything,
+                             "benchmarkanything-report" => \$benchmarkanything_report,
                              "cs-executable-suffix=s" => \$cs_executable_suffix,
                              "cs-executable=s"  => \$cs_executable,
                              "cs-project=s"     => \$cs_project,
@@ -582,6 +595,15 @@ sub run {
                              "tapdescription=s" => \$tapdescription,
                              "D=s%"             => \$D,
                             );
+
+        # special meta options - order matters!
+        $benchmarkanything = 1 if $tapper; # legacy option
+        $benchmarkanything = 1 if $benchmarkanything_report;
+        $platforminfo      = 1 if $benchmarkanything; # -p
+        $showconfig        = 4 if $benchmarkanything; # -cccc
+        $outstyle          = 'json' if $benchmarkanything and $outstyle !~ /^(json|yaml|yamlish)$/;
+        $outstyle          = 'json' if $benchmarkanything_report;
+
         # fill options
         $self->{options} = {
                             help           => $help,
@@ -596,6 +618,8 @@ sub run {
                             platforminfo   => $platforminfo,
                             codespeed      => $codespeed,
                             tapper         => $tapper,
+                            benchmarkanything => $benchmarkanything,
+                            benchmarkanything_report => $benchmarkanything_report,
                             cs_executable_suffix => $cs_executable_suffix,
                             cs_executable        => $cs_executable,
                             cs_project           => $cs_project,
@@ -612,6 +636,31 @@ sub run {
         do { usage;                exit  0 } if $help;
         do { usage;                exit -1 } if not $ok;
 
+        # Verify result storage before we start to avoid wasting benchmark time
+        if ($self->{options}{benchmarkanything_report})
+        {
+                print STDERR "# Wait for result store..." if $self->{options}{verbose} >= 2;
+                my $retry_sleep = 1;
+
+        RETRY:
+                eval {
+                        require BenchmarkAnything::Storage::Frontend::Lib;
+                        my $just_for_checking_balib = BenchmarkAnything::Storage::Frontend::Lib->new(verbose => $self->{options}{verbose});
+
+                        # dies if not available
+                        $just_for_checking_balib->connect;
+                        $just_for_checking_balib->disconnect;
+                        undef($just_for_checking_balib);
+                };
+                if ($@) {
+                        print STDERR "." if $self->{options}{verbose};
+                        sleep $retry_sleep;
+                        $retry_sleep *= 2 unless $retry_sleep > 3600; # exponential back-off until ~1h
+                        goto RETRY;
+                }
+                print STDERR "\n" if $self->{options}{verbose} >= 2;
+        }
+
         # use forks if requested
         if ($useforks) {
                 eval "use forks"; ## no critic
@@ -669,7 +718,7 @@ sub run {
         }
 
         # Tapper BenchmarkAnythingData blocks
-        if ($tapper)
+        if ($tapper or $benchmarkanything)
         {
                 $RESULTS{BenchmarkAnythingData} = $self->generate_BenchmarkAnythingData_data(\%RESULTS);
         }
@@ -773,6 +822,37 @@ sub print_results
                 print $OUTFILE $output;
                 close $OUTFILE;
         }
+        elsif ($self->{options}{benchmarkanything_report})
+        {
+                require BenchmarkAnything::Storage::Frontend::Lib;
+                my $balib = BenchmarkAnything::Storage::Frontend::Lib->new(verbose => $self->{options}{verbose});
+
+                eval {
+                        $balib->add({BenchmarkAnythingData => $RESULTS->{BenchmarkAnythingData}});
+                };
+                if ($@)
+                {
+                        print STDERR "# Could not add results to storage: $@\n";
+
+                        require JSON;
+                        require File::Path;
+                        require File::Temp;
+                        require File::Basename;
+
+                        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
+
+                        my $home_ba            = File::Basename::dirname($balib->{cfgfile});
+                        my $timestamp1         = sprintf("%04d-%02d-%02d", 1900+$year, $mon, $mday);
+                        my $timestamp2         = sprintf("%02d-%02d-%02d", $hour, $min, $sec);
+                        my $result_path        = "$home_ba/unreported_results/$timestamp1";
+
+                        File::Path::make_path($result_path);
+
+                        my ($FH, $result_file) = File::Temp::tempfile ("$timestamp2-XXXX", DIR => $result_path, SUFFIX => ".json");
+                        print STDERR "# Writing them to file: $result_file\n";
+                        print $FH JSON->new->allow_nonref->pretty->encode({BenchmarkAnythingData => $RESULTS->{BenchmarkAnythingData}});
+                }
+        }
         else
         {
                 print $output;
@@ -785,7 +865,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
