@@ -33,10 +33,10 @@ sub main {
                                     $result = 7;
                                    };
         return {
-                Benchmark             => $t,
-                goal                  => $goal,
-                count                 => $count,
-                result                => $result,
+                Benchmark             => $t,        # "Benchmark" is the only important key
+                goal                  => $goal,     # \
+                count                 => $count,    #  | Just meta info for debugging / arguing / questioning.
+                result                => $result,   # /
                };
 }
 
@@ -46,7 +46,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
